@@ -112,6 +112,11 @@ class SPALeRASGD
              const bool resetPolicy = true,
              const bool exactObjective = false);
 
+  /**
+   * Clean any memory associated with the SPALeRA SGD object.
+   */
+  ~SPALeRASGD();
+
   /**
    * Optimize the given function using SPALeRA SGD.  The given starting point
    * will be modified to store the finishing point of the algorithm, and the
